@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -452,49 +452,49 @@ static const struct {
 	const char *pattern;
 	const bool match;
 } testcases[] = {
-	{ "/bin/true", "/bin/\\*", 1 },
-	{ "/bin/true", "/bin\\@\\*/\\*", 1 },
+	{ BINDIR "/true", BINDIR "/\\*", 1 },
+	{ BINDIR "/true", BINDIR "\\@\\*/\\*", 1 },
 	{ "/usr/local/", "/usr/\\*/", 1 },
 	{ "/usr/local/", "/usr/\\*\\*\\@\\*/", 1 },
 	{ "pipe:[12345]", "pipe:[\\$]", 1 },
 	{ "socket:[family=1:type=2:protocol=3]",
 	  "socket:[family=1:type=2:protocol=\\$]", 1 },
-	{ "http://tomoyo.sourceforge.jp/", "\\*/\\*/\\*/", 1 },
-	{ "http://tomoyo.sourceforge.jp/index.html", "\\*/\\*/\\*/\\*", 1 },
-	{ "http://tomoyo.sourceforge.jp/index.html",
+	{ "https://tomoyo.osdn.jp/", "\\*/\\*/\\*/", 1 },
+	{ "https://tomoyo.osdn.jp/index.html", "\\*/\\*/\\*/\\*", 1 },
+	{ "https://tomoyo.osdn.jp/index.html",
 	  "\\*/\\*/\\*/\\*\\*\\@\\*\\@", 1 },
-	{ "http://tomoyo.sourceforge.jp/index.html",
+	{ "https://tomoyo.osdn.jp/index.html",
 	  "\\*/\\@\\*/\\*\\@/\\*\\@\\*\\@\\*", 1 },
-	{ "http://tomoyo.sourceforge.jp/1.7/index.html",
-	  "http://\\{\\*\\}/\\@.html", 1 },
-	{ "http://tomoyo.sourceforge.jp/index.html",
-	  "\\*://\\@.sourceforge.jp/\\*", 1 },
-	{ "http://tomoyo.sourceforge.jp/index.html",
-	  "\\*://\\@.sourceforge.jp/\\*", 1 },
-	{ "http://sourceforge.jp/projects/tomoyo/svn/view/trunk/1.7.x/"
+	{ "https://tomoyo.osdn.jp/1.7/index.html",
+	  "https://\\{\\*\\}/\\@.html", 1 },
+	{ "https://tomoyo.osdn.jp/index.html",
+	  "\\*://\\@.osdn.jp/\\*", 1 },
+	{ "https://tomoyo.osdn.jp/index.html",
+	  "\\*://\\@.osdn.jp/\\*", 1 },
+	{ "https://osdn.jp/projects/tomoyo/svn/view/trunk/1.7.x/"
 	  "ccs-patch/security/ccsecurity/?root=tomoyo",
-	  "\\*://\\@sourceforge.jp/\\{\\*\\}/?root=tomoyo", 1 },
-	{ "http://sourceforge.jp/projects/tomoyo/svn/view/trunk/1.7.x/"
+	  "\\*://\\@osdn.jp/\\{\\*\\}/?root=tomoyo", 1 },
+	{ "https://osdn.jp/projects/tomoyo/svn/view/trunk/1.7.x/"
 	  "ccs-patch/security/?root=tomoyo",
-	  "\\*://\\@sourceforge.jp/\\{\\*\\}/?root=tomoyo", 1 },
-	{ "http://sourceforge.jp/projects/tomoyo/svn/view/trunk/1.7.x/"
+	  "\\*://\\@osdn.jp/\\{\\*\\}/?root=tomoyo", 1 },
+	{ "https://osdn.jp/projects/tomoyo/svn/view/trunk/1.7.x/"
 	  "ccs-patch/?root=tomoyo",
-	  "\\*://\\@sourceforge.jp/\\{\\*\\}/?root=tomoyo", 1 },
-	{ "http://sourceforge.jp/projects/tomoyo/svn/view/trunk/1.7.x/"
+	  "\\*://\\@osdn.jp/\\{\\*\\}/?root=tomoyo", 1 },
+	{ "https://osdn.jp/projects/tomoyo/svn/view/trunk/1.7.x/"
 	  "/ccs-patch///security//ccsecurity///?root=tomoyo",
-	  "\\*://\\@sourceforge.jp/\\{\\*\\-.\\-..\\-\\*%\\*\\}/"
+	  "\\*://\\@osdn.jp/\\{\\*\\-.\\-..\\-\\*%\\*\\}/"
 	  "?root=tomoyo\\*\\*", 1 },
 	{ "/var/www/html/test/test/test/index.html",
 	  "/var/www/html/\\{test\\}/\\*.html", 1 },
 	{ "/etc/skel/", "/etc/\\{\\*\\}/\\*/", 0 },
 	{ "/etc/passwd", "/etc/\\{\\*\\}/\\*", 0 },
-	{ "/bin/true", "/bin/\\*/", 0 },
-	{ "/bin/", "/bin/\\*", 0 },
-	{ "/bin/", "/bin/\\@", 0 },
-	{ "/bin/", "/bin/\\@\\@", 0 },
-	{ "http://tomoyo.sourceforge.jp/", "\\*/\\*/\\*/\?", 0 },
-	{ "http://tomoyo.sourceforge.jp/index.html", "\\*/\\*/\\*/\\@", 0 },
-	{ "http://tomoyo.sourceforge.jp/index.html", "http://\\*/\\@", 0 },
+	{ BINDIR "/true", BINDIR "/\\*/", 0 },
+	{ BINDIR "/", BINDIR "/\\*", 0 },
+	{ BINDIR "/", BINDIR "/\\@", 0 },
+	{ BINDIR "/", BINDIR "/\\@\\@", 0 },
+	{ "https://tomoyo.osdn.jp/", "\\*/\\*/\\*/\?", 0 },
+	{ "https://tomoyo.osdn.jp/index.html", "\\*/\\*/\\*/\\@", 0 },
+	{ "https://tomoyo.osdn.jp/index.html", "https://\\*/\\@", 0 },
 	{ "socket:[family=1:type=2:protocol=3]",
 	  "/\\{\\*\\}/socket:[\\*]", 0 },
 	{ NULL, NULL, 0 }
