@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -121,7 +121,7 @@ static void stage_file_test(void)
 		fflush(stderr);
 		ret_ignored = pipe(pipe_fd);
 		if (fork() == 0) {
-			execl("/bin/true", "/bin/true", NULL);
+			execl(BINDIR "/true", BINDIR "/true", NULL);
 			err = errno;
 			ret_ignored = write(pipe_fd[1], &err, sizeof(err));
 			_exit(0);
