@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 2.5.0+   2014/01/05
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -924,7 +924,7 @@ static void make_profile(void)
 	fprintf(stderr, "Creating default profile... ");
 	if (file_only_profile)
 		file_only = "::file";
-	fprintf(fp, "PROFILE_VERSION=20110903\n");
+	fprintf(fp, "PROFILE_VERSION=20150505\n");
 	fprintf(fp, "0-COMMENT=-----Disabled Mode-----\n"
 		"0-PREFERENCE={ max_audit_log=%u max_learning_entry=%u }\n"
 		"0-CONFIG%s={ mode=disabled grant_log=%s reject_log=%s }\n",
@@ -951,7 +951,7 @@ static void make_profile(void)
 /* Which profile number does <kernel> domain use? */
 static unsigned char default_profile = 0;
 /* Which ACL group does <kernel> domain use? */
-static unsigned char default_group = 0;
+static _Bool use_group[256] = { };
 
 /**
  * make_domain_policy - Make /etc/tomoyo/policy/current/domain_policy.conf .
@@ -961,6 +961,7 @@ static unsigned char default_group = 0;
 static void make_domain_policy(void)
 {
 	FILE *fp;
+	int i;
 	if (!chdir_policy())
 		return;
 	if (!access("domain_policy.conf", R_OK))
@@ -971,8 +972,10 @@ static void make_domain_policy(void)
 		return;
 	}
 	fprintf(stderr, "Creating domain policy... ");
-	fprintf(fp, "<kernel>\nuse_profile %u\nuse_group %u\n",
-		default_profile, default_group);
+	fprintf(fp, "<kernel>\nuse_profile %u\n", default_profile);
+	for (i = 0; i < 256; i++)
+		if (use_group[i])
+			fprintf(fp, "use_group %u\n", i);
 	close_file(fp, 1, "domain_policy.tmp", "domain_policy.conf");
 }
 
@@ -1262,8 +1265,6 @@ static const char editpolicy_data[] =
 "keyword_alias acl_group 255                 = acl_group 255\n"
 "keyword_alias address_group                 = address_group\n"
 "keyword_alias aggregator                    = aggregator\n"
-"keyword_alias capability                    = capability\n"
-"keyword_alias deny_autobind                 = deny_autobind\n"
 "keyword_alias file append                   = file append\n"
 "keyword_alias file chgrp                    = file chgrp\n"
 "keyword_alias file chmod                    = file chmod\n"
@@ -1290,7 +1291,6 @@ static const char editpolicy_data[] =
 "keyword_alias file unmount                  = file unmount\n"
 "keyword_alias file write                    = file write\n"
 "keyword_alias initialize_domain             = initialize_domain\n"
-"keyword_alias ipc signal                    = ipc signal\n"
 "keyword_alias keep_domain                   = keep_domain\n"
 "keyword_alias misc env                      = misc env\n"
 "keyword_alias network inet                  = network inet\n"
@@ -1302,9 +1302,6 @@ static const char editpolicy_data[] =
 "keyword_alias path_group                    = path_group\n"
 "keyword_alias quota_exceeded                = quota_exceeded\n"
 "keyword_alias reset_domain                  = reset_domain\n"
-"keyword_alias task auto_domain_transition   = task auto_domain_transition\n"
-"keyword_alias task auto_execute_handler     = task auto_execute_handler\n"
-"keyword_alias task denied_execute_handler   = task denied_execute_handler\n"
 "keyword_alias task manual_domain_transition = task manual_domain_transition\n"
 "keyword_alias transition_failed             = transition_failed\n"
 "keyword_alias use_group                     = use_group\n"
@@ -1650,7 +1647,7 @@ int main(int argc, char *argv[])
 		} else if (!strncmp(arg, "use_profile=", 12)) {
 			default_profile = atoi(arg + 12);
 		} else if (!strncmp(arg, "use_group=", 10)) {
-			default_group = atoi(arg + 10);
+			use_group[(unsigned char) atoi(arg + 10)] = 1;
 		} else if (!strncmp(arg, "grant_log=", 10)) {
 			grant_log = arg + 10;
 		} else if (!strncmp(arg, "reject_log=", 11)) {
@@ -1664,6 +1661,11 @@ int main(int argc, char *argv[])
 	}
 	if (!dir)
 		dir = "/etc/tomoyo";
+	for (i = 0; i < 256; i++)
+		if (use_group[i])
+			break;
+	if (i == 256)
+		use_group[0] = 1;
 	policy_dir = strdup(dir);
 	memset(path, 0, sizeof(path));
 	make_policy_dir();
