@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 2.5.0+   2012/03/13
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -2259,10 +2259,12 @@ void ccs_mount_securityfs(void)
 {
 	if (access("/sys/kernel/security/tomoyo/", X_OK)) {
 		if (unshare(CLONE_NEWNS) ||
+		    mount(NULL, "/", NULL, MS_REC|MS_PRIVATE, NULL) ||
 		    mount("none", "/sys/kernel/security/", "securityfs", 0,
 			  NULL)) {
-			fprintf(stderr, "Please mount securityfs on "
-				"/sys/kernel/security/ .\n");
+			if (errno != EBUSY)
+				fprintf(stderr, "Please mount securityfs on "
+					"/sys/kernel/security/ .\n");
 		}
 	}
 }
